@@ -3,7 +3,16 @@ import datetime
 import typing
 import uuid
 
-from commercetools import schemas, types
+from commercetools import types
+from commercetools._schemas._cart import CartSchema, ShippingInfoSchema
+from commercetools._schemas._order import (
+    DeliverySchema,
+    OrderFromCartDraftSchema,
+    OrderPagedQueryResponseSchema,
+    OrderSchema,
+    OrderUpdateSchema,
+)
+from commercetools._schemas._payment import PaymentReferenceSchema
 from commercetools.testing.abstract import BaseModel, ServiceBackend
 from commercetools.testing.utils import (
     set_custom_field,
@@ -15,7 +24,7 @@ from commercetools.types import CartOrigin, OrderState
 
 class OrdersModel(BaseModel):
     _primary_type_name = "order"
-    _resource_schema = schemas.OrderSchema
+    _resource_schema = OrderSchema
 
     def _create_from_draft(
         self, draft: types.OrderFromCartDraft, id: typing.Optional[str] = None
@@ -27,11 +36,24 @@ class OrdersModel(BaseModel):
         """
 
         object_id = str(uuid.UUID(id) if id is not None else uuid.uuid4())
+        cart_identifier = types.CartResourceIdentifier(id=draft.id)
+
+        cart_data = self._storage.get_by_resource_identifier(cart_identifier)
+        cart = None
+        if cart_data:
+            cart = CartSchema().load(cart_data)
+
         order = types.Order(
             id=str(object_id),
             version=1,
             created_at=datetime.datetime.now(datetime.timezone.utc),
             last_modified_at=datetime.datetime.now(datetime.timezone.utc),
+            line_items=[],
+            custom_line_items=[],
+            total_price=copy.deepcopy(cart.total_price),
+            sync_info=[],
+            last_message_sequence_number=0,
+            refused_gifts=[],
             order_number=draft.order_number,
             payment_state=draft.payment_state,
             order_state=OrderState.OPEN,
@@ -46,6 +68,7 @@ def add_delivery():
         delivery = types.Delivery(
             id=str(uuid.uuid4()),
             created_at=datetime.datetime.now(datetime.timezone.utc),
+            items=[],
             parcels=[
                 types.Parcel(
                     id=str(uuid.uuid4()),
@@ -59,13 +82,13 @@ def add_delivery():
         )
 
         if not obj["shippingInfo"]:
-            obj["shippingInfo"] = schemas.ShippingInfoSchema().dump(
+            obj["shippingInfo"] = ShippingInfoSchema().dump(
                 types.ShippingInfo(deliveries=[])
             )
         elif not obj["shippingInfo"]["deliveries"]:
             obj["shippingInfo"]["deliveries"] = []
 
-        value = schemas.DeliverySchema().dump(delivery)
+        value = DeliverySchema().dump(delivery)
         if value not in obj["shippingInfo"]["deliveries"]:
             new = copy.deepcopy(obj)
             new["shippingInfo"]["deliveries"].append(value)
@@ -83,7 +106,7 @@ def add_payment():
         else:
             payments = []
 
-        payments.append(schemas.PaymentReferenceSchema().dump(action.payment))
+        payments.append(PaymentReferenceSchema().dump(action.payment))
         obj["paymentInfo"] = {"payments": payments}
         return obj
 
@@ -93,9 +116,9 @@ def add_payment():
 class OrdersBackend(ServiceBackend):
     service_path = "orders"
     model_class = OrdersModel
-    _schema_draft = schemas.OrderFromCartDraftSchema
-    _schema_update = schemas.OrderUpdateSchema
-    _schema_query_response = schemas.OrderPagedQueryResponseSchema
+    _schema_draft = OrderFromCartDraftSchema
+    _schema_update = OrderUpdateSchema
+    _schema_query_response = OrderPagedQueryResponseSchema
 
     def urls(self):
         return [
