@@ -2,14 +2,18 @@ from commercetools import types
 
 
 def test_inventory_create(client):
-    inventory = client.inventory.create(types.InventoryEntryDraft(quantity_on_stock=10))
+    inventory = client.inventory.create(
+        types.InventoryEntryDraft(sku="1", quantity_on_stock=10)
+    )
 
     assert inventory.id
     assert inventory.quantity_on_stock == 10
 
 
 def test_inventory_get_by_id(client):
-    inventory = client.inventory.create(types.InventoryEntryDraft(quantity_on_stock=10))
+    inventory = client.inventory.create(
+        types.InventoryEntryDraft(sku="1", quantity_on_stock=10)
+    )
 
     assert inventory.id
     assert inventory.quantity_on_stock == 10
@@ -20,7 +24,9 @@ def test_inventory_get_by_id(client):
 
 
 def test_inventory_update_by_id(client):
-    inventory = client.inventory.create(types.InventoryEntryDraft(quantity_on_stock=10))
+    inventory = client.inventory.create(
+        types.InventoryEntryDraft(sku="1", quantity_on_stock=10)
+    )
 
     assert inventory.id
     assert inventory.quantity_on_stock == 10
